from PyQt5.QtWebKit import (
    QWebDatabase,
    QWebElement,
    QWebElementCollection,
    QWebHistory,
    QWebHistoryInterface,
    QWebHistoryItem,
    QWebPluginFactory,
    QWebSecurityOrigin,
    QWebSettings,
    qWebKitMajorVersion,
    qWebKitMinorVersion,
    qWebKitVersion
)

from PyQt5.QtWebKitWidgets import (
    QGraphicsWebView,
    QWebFrame,
    QWebHitTestResult,
    QWebInspector,
    QWebPage,
    QWebView,
)